<?php
/**
 * SantaMas functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package SantaMas
 */

if ( ! function_exists( 'santamas_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function santamas_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on Santa, use a find and replace
		 * to change 'santamas' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'santamas', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );
		add_image_size( 'santamas-blog-thumb', 420, 290, true);
		add_image_size( 'santamas-blog-banner', 820, 400, true);
		add_image_size( 'santamas-gallery-thumb', 380, 400, true);

		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'santamas-main-menu' => esc_html__( 'Main Menu', 'santamas' ),
			'santamas-footer-menu' => esc_html__( 'Footer Menu', 'santamas' ),
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'santamas_custom_background_args', array(
			'default-color' => 'ffffff',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 60,
			'width'       => 200,
			'flex-width'  => true,
			'flex-height' => true,
		) );
	}
endif;
add_action( 'after_setup_theme', 'santamas_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function santamas_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'santamas_content_width', 740 );
}
add_action( 'after_setup_theme', 'santamas_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function santamas_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'santamas' ),
		'id'            => 'sidebar-right',
		'description'   => esc_html__( 'Add widgets here.', 'santamas' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
	) );
}
add_action( 'widgets_init', 'santamas_widgets_init' );


if ( ! function_exists( 'santamas_fonts_url' ) ) :
/**
 * Register Google fonts for Santa.
 *
 * @since SantaMas 1.0
 *
 * @return string Google fonts URL for the theme.
 */
function santamas_fonts_url() {
	$fonts_url = '';
	$fonts     = array();
	$subsets   = 'latin,latin-ext';

	/*
	 * Translators: If there are characters in your language that are not supported
	 * by Open Sans, translate this to 'off'. Do not translate into your own language.
	 */
	if ( 'off' !== _x( 'on', 'Roboto Sans font: on or off', 'santamas' ) ) {
		$fonts[] = 'Roboto:300,400,400i,700,700i';
	}

	/*
	 * Translators: If there are characters in your language that are not supported
	 * by Inconsolata, translate this to 'off'. Do not translate into your own language.
	 */
	if ( 'off' !== _x( 'on', 'Noto Serif: on or off', 'santamas' ) ) {
		$fonts[] = 'Noto+Serif:400,400i,700,700i';
	}

	/*
	 * Translators: To add an additional character subset specific to your language,
	 * translate this to 'greek', 'cyrillic', 'devanagari' or 'vietnamese'. Do not translate into your own language.
	 */
	$subset = _x( 'no-subset', 'Add new subset (greek, cyrillic, devanagari, vietnamese)', 'santamas' );

	if ( 'cyrillic' == $subset ) {
		$subsets .= ',cyrillic,cyrillic-ext';
	} elseif ( 'greek' == $subset ) {
		$subsets .= ',greek,greek-ext';
	} elseif ( 'devanagari' == $subset ) {
		$subsets .= ',devanagari';
	} elseif ( 'vietnamese' == $subset ) {
		$subsets .= ',vietnamese';
	}

	if ( $fonts ) {
		$fonts_url = add_query_arg( array(
			'family' =>  implode( '|', $fonts ) ,
			'subset' =>  $subsets ,
		), '//fonts.googleapis.com/css' );
	}

	return $fonts_url;
}
endif;

/**
 * Enqueue scripts and styles.
 */
function santamas_scripts() {
	wp_enqueue_style( 'santamas-fonts', santamas_fonts_url(), array(), null );
	wp_enqueue_style( 'lightgallery', get_template_directory_uri() .'/assets/lightgallery/css/lightgallery.css');
	wp_enqueue_style( 'lightslider', get_template_directory_uri() .'/assets/lightslider/css/lightslider.css');
	wp_enqueue_style( 'font-awesome', get_template_directory_uri() .'/css/font-awesome.css');
	wp_enqueue_style( 'santamas-style', get_stylesheet_uri(), array(), '1.01');

	wp_enqueue_script( 'snowfall-jquery', get_template_directory_uri() . '/js/snowfall.jquery.js', array(), '1.0', true );
	wp_enqueue_script( 'jquery-countdown', get_template_directory_uri() . '/js/jquery.countdown.js', array(), '1.0', true );
	wp_enqueue_script( 'lightgallery', get_template_directory_uri() . '/assets/lightgallery/js/lightgallery.js', array('jquery'), '1.0', true );
	wp_enqueue_script( 'lightslider', get_template_directory_uri() . '/assets/lightslider/js/lightslider.js', array('jquery'), '1.0', true );
	
	$banner_effect = get_theme_mod('santamas_banner_effect', 'none');
	$featured_effect = get_theme_mod('santamas_featured_effect', 'none');
	wp_enqueue_script( 'santamas-custom', get_template_directory_uri() . '/js/custom.js', array('jquery'), '1.0', true );
	wp_localize_script( 'santamas-custom' , 'santamas_params', array(
		'site_url' => get_template_directory_uri(),
		'banner_effect' => $banner_effect,
		'featured_effect' => $featured_effect
	));

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'santamas_scripts' );

/**
 * FontAwesome additions.
 */
require get_template_directory() . '/inc/font-awesome-list.php';

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}

/**
 * Load WooCommerce compatibility file.
 */
if ( class_exists( 'WooCommerce' ) ) {
	require get_template_directory() . '/inc/woocommerce.php';
}

/**
 * Load Admin Notice for starter content
 */
require get_template_directory() . '/inc/admin-notice.php';